@@ -162,7 +162,10 @@ class OpenEuler():
         while current_value != prev_value:
             prev_value = current_value
             for pattern, replacement in patterns:
-                current_value = pattern.sub(replacement, current_value)
+                try:
+                    current_value = pattern.sub(replacement, current_value)
+                except Exception as e:
+                    continue
         return current_value
 
 
